@@ -1,9 +1,8 @@
-use 5.008001;
-use strict;
+use v5.12.0;
 use warnings;
-package Email::MIME;
+package Email::MIME 1.953;
 # ABSTRACT: easy MIME message handling
-$Email::MIME::VERSION = '1.952';
+
 use Email::Simple 2.212; # nth header value
 use parent qw(Email::Simple);
 
@@ -14,7 +13,6 @@ use Email::MIME::ContentType 1.023; # build_content_type
 use Email::MIME::Encode;
 use Email::MIME::Encodings 1.314;
 use Email::MIME::Header;
-use Email::MIME::Modifier;
 use Encode 1.9801 ();
 use Scalar::Util qw(reftype weaken);
 
@@ -174,10 +172,9 @@ sub new {
 #pod
 #pod C<attributes> is a hash of MIME attributes to assign to the part, and may
 #pod override portions of the header set in the C<header> parameter. The hash keys
-#pod correspond directly to methods for modifying a message from
-#pod C<Email::MIME::Modifier>. The allowed keys are: content_type, charset, name,
-#pod format, boundary, encoding, disposition, and filename. They will be mapped to
-#pod C<"$attr\_set"> for message modification.
+#pod correspond directly to methods for modifying a message. The allowed keys are:
+#pod content_type, charset, name, format, boundary, encoding, disposition, and
+#pod filename. They will be mapped to C<"$attr\_set"> for message modification.
 #pod
 #pod The C<parts> parameter is a list reference containing C<Email::MIME>
 #pod objects. Elements of the C<parts> list can also be a non-reference
@@ -394,8 +391,7 @@ sub parts_multipart {
   # that means it's a bogus message, but a mangled result (or exception) is
   # better than endless recursion. -- rjbs, 2008-01-07
   return $self->parts_single_part
-    unless defined $boundary and length $boundary and
-           $self->body_raw =~ /^--\Q$boundary\E\s*$/sm;
+    unless length $boundary and $self->body_raw =~ /^--\Q$boundary\E\s*$/sm;
 
   $self->{body_raw} = $self->SUPER::body;
 
@@ -551,7 +547,7 @@ sub boundary_set {
   my ($self, $value) = @_;
   my $ct_header = parse_content_type($self->header('Content-Type'));
 
-  if (defined $value and length $value) {
+  if (length $value) {
     $ct_header->{attributes}->{boundary} = $value;
   } else {
     delete $ct_header->{attributes}->{boundary};
@@ -650,8 +646,6 @@ sub encoding_set {
 #pod specified in the C<Content-Transfer-Encoding> header, then set
 #pod the body to the new encoded body.
 #pod
-#pod This method overrides the default C<body_set()> method.
-#pod
 #pod =cut
 
 sub body_set {
@@ -769,7 +763,7 @@ sub parts_set {
 
     # setup multipart
     $ct_header->{attributes}->{boundary} = Email::MessageID->new->user
-      unless defined $ct_header->{attributes}->{boundary} and length $ct_header->{attributes}->{boundary};
+      unless length $ct_header->{attributes}->{boundary};
     my $bound = $ct_header->{attributes}->{boundary};
     foreach my $part (@{$parts}) {
       $body .= "$self->{mycrlf}--$bound$self->{mycrlf}";
@@ -908,10 +902,7 @@ sub _reset_cids {
     if ($ct_header->{subtype} eq 'alternative') {
       my %cids;
       for my $part ($self->parts) {
-        my $cid
-          = defined $part->header('Content-ID')
-          ? $part->header('Content-ID')
-          : q{};
+        my $cid = $part->header('Content-ID') // q{};
         $cids{$cid}++;
       }
       return if keys(%cids) == 1;
@@ -940,7 +931,7 @@ Email::MIME - easy MIME message handling
 
 =head1 VERSION
 
-version 1.952
+version 1.953
 
 =head1 SYNOPSIS
 
@@ -1082,10 +1073,9 @@ C<header_str>.  Its values will be used verbatim.
 
 C<attributes> is a hash of MIME attributes to assign to the part, and may
 override portions of the header set in the C<header> parameter. The hash keys
-correspond directly to methods for modifying a message from
-C<Email::MIME::Modifier>. The allowed keys are: content_type, charset, name,
-format, boundary, encoding, disposition, and filename. They will be mapped to
-C<"$attr\_set"> for message modification.
+correspond directly to methods for modifying a message. The allowed keys are:
+content_type, charset, name, format, boundary, encoding, disposition, and
+filename. They will be mapped to C<"$attr\_set"> for message modification.
 
 The C<parts> parameter is a list reference containing C<Email::MIME>
 objects. Elements of the C<parts> list can also be a non-reference
@@ -1165,8 +1155,6 @@ This method will encode the new body you send using the encoding
 specified in the C<Content-Transfer-Encoding> header, then set
 the body to the new encoded body.
 
-This method overrides the default C<body_set()> method.
-
 =head2 body_str_set
 
   $email->body_str_set($unicode_str);
@@ -1354,15 +1342,9 @@ The variable C<$Email::MIME::MAX_DEPTH> is the maximum depth of parts that will
 be processed.  It defaults to 10, already higher than legitimate mail is ever
 likely to be.  This value may go up over time as the parser is improved.
 
-=head1 TODO
-
-All of the Email::MIME-specific guts should move to a single entry on the
-object's guts.  This will require changes to both Email::MIME and
-L<Email::MIME::Modifier>, sadly.
-
 =head1 SEE ALSO
 
-L<Email::Simple>, L<Email::MIME::Modifier>, L<Email::MIME::Creator>.
+L<Email::Simple>
 
 =head1 THANKS
 
@@ -1375,7 +1357,7 @@ This module was generously sponsored by Best Practical
 
 =item *
 
-Ricardo SIGNES <rjbs@semiotic.systems>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =item *
 
@@ -1389,7 +1371,7 @@ Simon Cozens <simon@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alex Vandiver Anirvan Chatterjee Arthur Axel 'fREW' Schmidt Brian Cassidy Damian Lukowski Dan Book David Steinbrunner Dotan Dimet dxdc Eric Wong Geraint Edwards ivulfson Jesse Luehrs Kurt Anderson Lance A. Brown Matthew Horsfall memememomo Michael McClimon Mishrakk Pali Shawn Sorichetti Tomohiro Hosaka
+=for stopwords Alex Vandiver Anirvan Chatterjee Arthur Axel 'fREW' Schmidt Brian Cassidy Damian Lukowski Dan Book David Steinbrunner Dotan Dimet dxdc Eric Wong Geraint Edwards ivulfson Jesse Luehrs Kurt Anderson Lance A. Brown Matthew Horsfall memememomo Michael McClimon Mishrakk Pali Ricardo Signes Shawn Sorichetti Tomohiro Hosaka
 
 =over 4
 
@@ -1475,6 +1457,10 @@ Pali <pali@cpan.org>
 
 =item *
 
+Ricardo Signes <rjbs@semiotic.systems>
+
+=item *
+
 Shawn Sorichetti <ssoriche@coloredblocks.com>
 
 =item *
@@ -1620,15 +1606,9 @@ __END__
 #pod be processed.  It defaults to 10, already higher than legitimate mail is ever
 #pod likely to be.  This value may go up over time as the parser is improved.
 #pod
-#pod =head1 TODO
-#pod
-#pod All of the Email::MIME-specific guts should move to a single entry on the
-#pod object's guts.  This will require changes to both Email::MIME and
-#pod L<Email::MIME::Modifier>, sadly.
-#pod
 #pod =head1 SEE ALSO
 #pod
-#pod L<Email::Simple>, L<Email::MIME::Modifier>, L<Email::MIME::Creator>.
+#pod L<Email::Simple>
 #pod
 #pod =head1 THANKS
 #pod
